@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2015, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -20,9 +20,9 @@ package ch.qos.logback.core.util;
  * @since 1.1.0
  */
 public interface DelayStrategy {
-  /**
-   * The value computed by this {@code DelayStrategy} for the next delay.
-   * @return a delay value
-   */
-  int nextDelay();
+    /**
+     * The value computed by this {@code DelayStrategy} for the next delay.
+     * @return a delay value
+     */
+    long nextDelay();
 }
